@@ -89,21 +89,11 @@ class Drive(NetBoxModel):
         ordering = ['size']
 
     def __str__(self):
-        return f'{self.identifier} ({self.size} MB {self.cluster})'
+        return f'{self.identifier} ({self.size} GB {self.cluster})'
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_storage:drive', kwargs={'pk': self.pk})
 
-    def save(self, *args, **kwargs):
-        is_already_implemented = Drive.objects.filter(id=self.pk).count()
-        if is_already_implemented == 0:
-            number_of_hard_drives = Drive.objects.all().\
-                order_by('created').count()
-
-            self.identifier = f'Hard Drive {number_of_hard_drives + 1}'
-
-        super(Drive, self).save(*args, **kwargs)
-
     @property
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/drive/'
@@ -139,7 +129,7 @@ class Partition(NetBoxModel):
         verbose_name='Filesystem',
     )
     letter = models.CharField(
-        max_length=1,
+        max_length=255,
     )
     description = models.CharField(
         max_length=255,
