@@ -69,12 +69,20 @@ class PlatformTemplateContent(PluginTemplateExtension):
                                                                         object_id=linux_device_drive.pk,
                                                                         type='Partition'))
 
-        return self.render(
-            "netbox_storage/inc/template_drive_box.html",
-            extra_context={
-                "partition_dict": partition_dict
-            }
-        )
+        if obj.name.lower().__contains__('windows'):
+            return self.render(
+                "netbox_storage/inc/template_windows_drive_box.html",
+                extra_context={
+                    "partition_dict": partition_dict,
+                },
+            )
+        else:
+            return self.render(
+                "netbox_storage/inc/template_drive_box.html",
+                extra_context={
+                    "partition_dict": partition_dict
+                }
+            )
 
     def left_page(self):
         mounted_volumes = MountedVolume.objects.all()
